@@ -3,9 +3,9 @@ from importlib.metadata import version, PackageNotFoundError
 
 ROOT_PATH = Path(__file__).resolve().parent.parent
 
-__distribution_name = "treeplots"
+__distribution_name = 'treeplots'
 
 try:
     PACKAGE_VERSION = version(__distribution_name)
 except PackageNotFoundError:
-    PACKAGE_VERSION = "unknown"
+    PACKAGE_VERSION = 'unknown'
