@@ -1,5 +1,5 @@
 class COL:
-    CHILD_ID = "child_id"
+    CHILD_ID = 'child_id'
     PARENT_ID = 'parent_id'
     CHILD_NAME = 'eng_name'
     AS_OF = 'year'
